======================================
Collected examples
======================================

Here we collect a number of different example model files. The Yukawa model file is self-contained, but to save repeated code over the different examples, we have written an example base code, which the specific models utilise.


.. toctree::

    examples/wallGoExampleBase
    examples/standardModel
    examples/singletScalarExtension
    examples/singletScalarExtensionCollisions
    examples/singletScalarExtensionThermodynamics
    examples/manySinglets
    examples/inertDoubletModel
    examples/yukawa
    examples/yukawaCollisionForPairs